@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -25,9 +25,10 @@ class FilterIcecoveAbstract : public MailImporter::FilterIcedove
 public:
     FilterIcecoveAbstract()
     {
-
     }
-    QString settingsPath() Q_DECL_OVERRIDE {
+
+    QString settingsPath() override
+    {
         return MailImporter::FilterIcedove::settingsPath();
     }
 };
@@ -35,12 +36,10 @@ public:
 FilterIcedoveTest::FilterIcedoveTest(QObject *parent)
     : QObject(parent)
 {
-
 }
 
 FilterIcedoveTest::~FilterIcedoveTest()
 {
-
 }
 
 void FilterIcedoveTest::shouldHaveDefaultSettingsPath()
@@ -51,7 +50,6 @@ void FilterIcedoveTest::shouldHaveDefaultSettingsPath()
 
 void FilterIcedoveTest::shouldImportData()
 {
-
 }
 
 void FilterIcedoveTest::canNotImportDataEmptyPath()
@@ -86,4 +84,5 @@ void FilterIcedoveTest::canNotImportDataWhenHomeDirSelected()
     filter.importMails(QDir::homePath());
     QVERIFY(importerTest->filterImporterDataList().isEmpty());
 }
+
 QTEST_MAIN(FilterIcedoveTest)
